==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1FCVolumeSourceFluent.java <==
package io.kubernetes.client.models;

import java.lang.Integer;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Predicate;

public interface V1FCVolumeSourceFluent<A extends V1FCVolumeSourceFluent<A>> extends Fluent<A>{


    public String getFsType();
    public A withFsType(String fsType);
    public Boolean hasFsType();
    public Integer getLun();
    public A withLun(Integer lun);
    public Boolean hasLun();
    public A withNewLun(int arg1);
    public A withNewLun(String arg1);
    public Boolean isReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(boolean arg1);
    public A withNewReadOnly(String arg1);
    public A addToTargetWWNs(int index,String item);
    public A setToTargetWWNs(int index,String item);
    public A addToTargetWWNs(String... items);
    public A addAllToTargetWWNs(Collection<String> items);
    public A removeFromTargetWWNs(String... items);
    public A removeAllFromTargetWWNs(Collection<String> items);
    public List<String> getTargetWWNs();
    public String getTargetWWN(int index);
    public String getFirstTargetWWN();
    public String getLastTargetWWN();
    public String getMatchingTargetWWN(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withTargetWWNs(List<String> targetWWNs);
    public A withTargetWWNs(String... targetWWNs);
    public Boolean hasTargetWWNs();
    public A addToWwids(int index,String item);
    public A setToWwids(int index,String item);
    public A addToWwids(String... items);
    public A addAllToWwids(Collection<String> items);
    public A removeFromWwids(String... items);
    public A removeAllFromWwids(Collection<String> items);
    public List<String> getWwids();
    public String getWwid(int index);
    public String getFirstWwid();
    public String getLastWwid();
    public String getMatchingWwid(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withWwids(List<String> wwids);
    public A withWwids(String... wwids);
    public Boolean hasWwids();



}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1FCVolumeSourceFluent.java <==
package io.kubernetes.client.models;

import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Predicate;

public interface V1FCVolumeSourceFluent<A extends V1FCVolumeSourceFluent<A>> extends Fluent<A>{


    public String getFsType();
    public A withFsType(String fsType);
    public Boolean hasFsType();
    public A withNewFsType(String arg1);
    public A withNewFsType(StringBuilder arg1);
    public A withNewFsType(StringBuffer arg1);
    public Integer getLun();
    public A withLun(Integer lun);
    public Boolean hasLun();
    public Boolean isReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(String arg1);
    public A withNewReadOnly(boolean arg1);
    public A addToTargetWWNs(int index,String item);
    public A setToTargetWWNs(int index,String item);
    public A addToTargetWWNs(String... items);
    public A addAllToTargetWWNs(Collection<String> items);
    public A removeFromTargetWWNs(String... items);
    public A removeAllFromTargetWWNs(Collection<String> items);
    public List<String> getTargetWWNs();
    public String getTargetWWN(int index);
    public String getFirstTargetWWN();
    public String getLastTargetWWN();
    public String getMatchingTargetWWN(io.kubernetes.client.fluent.Predicate<String> predicate);
    public Boolean hasMatchingTargetWWN(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withTargetWWNs(List<String> targetWWNs);
    public A withTargetWWNs(String... targetWWNs);
    public Boolean hasTargetWWNs();
    public A addNewTargetWWN(String arg1);
    public A addNewTargetWWN(StringBuilder arg1);
    public A addNewTargetWWN(StringBuffer arg1);
    public A addToWwids(int index,String item);
    public A setToWwids(int index,String item);
    public A addToWwids(String... items);
    public A addAllToWwids(Collection<String> items);
    public A removeFromWwids(String... items);
    public A removeAllFromWwids(Collection<String> items);
    public List<String> getWwids();
    public String getWwid(int index);
    public String getFirstWwid();
    public String getLastWwid();
    public String getMatchingWwid(io.kubernetes.client.fluent.Predicate<String> predicate);
    public Boolean hasMatchingWwid(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withWwids(List<String> wwids);
    public A withWwids(String... wwids);
    public Boolean hasWwids();
    public A addNewWwid(String arg1);
    public A addNewWwid(StringBuilder arg1);
    public A addNewWwid(StringBuffer arg1);



}
